@@ -1,7 +1,7 @@
 import requests
 from urllib.parse import quote
 from django.conf import settings
-from pychance.client.api import CommonAPIClient
+from appchance.client.api import CommonAPIClient
 
 
 class ClientGraphQL(CommonAPIClient):
@@ -10,7 +10,6 @@ class ClientGraphQL(CommonAPIClient):
 
     def __init__(self, *args, **kwargs):
         super().__init__(self, *args, **kwargs)
-        self.endpoint = kwargs.get("endpoint")
 
     @staticmethod
     def _prepare_query(root, params, extra, mutation=False):
@@ -27,17 +26,17 @@ class ClientGraphQL(CommonAPIClient):
         return _str
 
     def query(self, root, params, extra):
-        kwargs = {"basic": self.basic} if self.basic else {}
+        kwargs = {"basic": self.basic} if self.basic else {}  # pylint: disable=no-member
         return self.do_request(
             "GET",
-            self.endpoint,
+            self.endpoint,  # pylint: disable=no-member
             payload={"query": self._prepare_query(root, params, extra)},
             **kwargs)
     
     def mutation(self, root, params, extra):
-        kwargs = {"basic": self.basic} if self.basic else {}
+        kwargs = {"basic": self.basic} if self.basic else {}  # pylint: disable=no-member
         return self.do_request(
             "POST",
-            self.endpoint,
+            self.endpoint,  # pylint: disable=no-member
             payload={"query": self._prepare_query(root, params, extra, mutation=True)},
             **kwargs)
